<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="en_US">
<context>
    <name>ORFDialogBase</name>
    <message>
        <source>find_dialog_caption</source>
        <translation type="obsolete">Find ORFs in sequence</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="41"/>
        <source>find_dialog_wit</source>
        <translation>Find Open Reading Frames in sequence</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="60"/>
        <source>strand_group</source>
        <translation>Strand</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="72"/>
        <source>strand_both</source>
        <translation>Both</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="82"/>
        <location filename="../src/ui/ORFDialogUI.ui" line="85"/>
        <source>strand_direct_wit</source>
        <translation>Search frames in direct strand only</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="88"/>
        <source>strand_direct_label</source>
        <translation>Direct</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="101"/>
        <location filename="../src/ui/ORFDialogUI.ui" line="104"/>
        <source>strand_complement_wit</source>
        <translation>Search frames in complement strand only</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="107"/>
        <source>strand_complement_label</source>
        <translation>Complement</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="126"/>
        <source>param_group</source>
        <translation>ORF Search parameters</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="140"/>
        <source>min_len_label</source>
        <translation>Min length, bp:</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="189"/>
        <source>must_fit_label</source>
        <translation>Must terminate within region</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="202"/>
        <source>must_init_label</source>
        <translation>Must start with init codon</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="212"/>
        <source>allow_overlap_tip</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="215"/>
        <source>Allow overlap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="231"/>
        <source>allow_alternative_label</source>
        <translation>Allow alternative init codons</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="257"/>
        <source>find_all_wit</source>
        <translation>Start searching ORFs</translation>
    </message>
    <message>
        <source>find_all_button</source>
        <translation type="obsolete">Search</translation>
    </message>
    <message>
        <source>hide_button_wit</source>
        <translation type="obsolete">Stop the search then leave the dialog</translation>
    </message>
    <message>
        <source>close_button</source>
        <translation type="obsolete">Close</translation>
    </message>
    <message>
        <source>save_as_features_tt</source>
        <translation type="obsolete">Save results as annotations</translation>
    </message>
    <message>
        <source>save_as_features_wit</source>
        <translation type="obsolete">Save results as annotations</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="282"/>
        <source>clear_list_button</source>
        <translation>Clear results</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="364"/>
        <source>rstart_label</source>
        <translation>Range start:</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="400"/>
        <source>rend_label</source>
        <translation>Range end:</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="134"/>
        <location filename="../src/ui/ORFDialogUI.ui" line="137"/>
        <location filename="../src/ORFQuery.cpp" line="197"/>
        <location filename="../src/ORFWorker.cpp" line="80"/>
        <source>min_len_tip</source>
        <translation>Ignore ORFs shorter than the specified length</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="35"/>
        <source>Find ORFs settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="183"/>
        <location filename="../src/ui/ORFDialogUI.ui" line="186"/>
        <location filename="../src/ORFWorker.cpp" line="81"/>
        <source>must_fit_tip</source>
        <translation>Ignore boundary ORFs which last beyound the search region
(i.e. have no stop codon within the range).</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="196"/>
        <location filename="../src/ui/ORFDialogUI.ui" line="199"/>
        <location filename="../src/ORFQuery.cpp" line="198"/>
        <location filename="../src/ORFWorker.cpp" line="82"/>
        <source>must_init_tip</source>
        <translation>Specifies that each ORF found must start with the start codon</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="225"/>
        <location filename="../src/ui/ORFDialogUI.ui" line="228"/>
        <location filename="../src/ORFQuery.cpp" line="199"/>
        <location filename="../src/ORFWorker.cpp" line="83"/>
        <source>allow_alt_tip</source>
        <translation>Allow ORFs starting with alternative initiation codons, 
accordingly to the current translation table.</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="66"/>
        <location filename="../src/ui/ORFDialogUI.ui" line="69"/>
        <source>strand_both_wit</source>
        <translation>Search in both strands</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="260"/>
        <source>Preview</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="443"/>
        <location filename="../src/ui/ORFDialogUI.ui" line="446"/>
        <source>sel_bt_tip</source>
        <translation>Set the range to current sequence selection</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="430"/>
        <location filename="../src/ui/ORFDialogUI.ui" line="433"/>
        <source>pv_bt_tip</source>
        <translation>Set the range to Panoramic View range</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="456"/>
        <location filename="../src/ui/ORFDialogUI.ui" line="459"/>
        <source>seq_bt_tip</source>
        <translation>Set the range to the whole sequence</translation>
    </message>
    <message>
        <source>save_as_annotations</source>
        <translation type="obsolete">Save as annotations..</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="344"/>
        <source>region</source>
        <translation>Location</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="349"/>
        <source>compl</source>
        <translation>Strand</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="354"/>
        <source>len</source>
        <translation>Length</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="449"/>
        <source>Selection range</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="436"/>
        <source>Overview range</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="462"/>
        <source>Sequence range</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>U2::FindORFsToAnnotationsTask</name>
    <message>
        <location filename="../src/ORFMarkerTask.cpp" line="77"/>
        <source>Find ORFs and save to annotations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ORFMarkerTask.cpp" line="102"/>
        <source>Annotation obj %1 is locked for modifications</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::LocalWorkflow::ORFPrompter</name>
    <message>
        <location filename="../src/ORFWorker.cpp" line="153"/>
        <source>unset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ORFWorker.cpp" line="154"/>
        <source> from &lt;u&gt;%1&lt;/u&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ORFWorker.cpp" line="165"/>
        <source>, allow ORFs &lt;u&gt;starting with any codon&lt;/u&gt; other than terminator</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ORFWorker.cpp" line="167"/>
        <source>, take into account &lt;u&gt;alternative start codons&lt;/u&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ORFWorker.cpp" line="170"/>
        <source>, &lt;u&gt;ignore non-terminated&lt;/u&gt; ORFs</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ORFWorker.cpp" line="187"/>
        <source>For each nucleotide sequence%1, find ORFs in &lt;u&gt;%2&lt;/u&gt; using the &lt;u&gt;%3&lt;/u&gt;.&lt;br&gt;Detect only ORFs &lt;u&gt;not shorter than %4 bps&lt;/u&gt;%5.&lt;br&gt;Output the list of found regions annotated as &lt;u&gt;%6&lt;/u&gt;.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::LocalWorkflow::ORFWorker</name>
    <message>
        <location filename="../src/ORFWorker.cpp" line="277"/>
        <source>Found %1 ORFs</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ORFWorker.cpp" line="65"/>
        <source>Input sequences</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ORFWorker.cpp" line="67"/>
        <source>ORF annotations</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ORFWorker.cpp" line="79"/>
        <source>Genetic code</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ORFWorker.cpp" line="81"/>
        <source>Require stop codon</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ORFWorker.cpp" line="82"/>
        <source>Require init codon</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ORFWorker.cpp" line="83"/>
        <source>Allow alternative codons</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ORFWorker.cpp" line="175"/>
        <source>both strands</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ORFWorker.cpp" line="176"/>
        <source>direct strand</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ORFWorker.cpp" line="177"/>
        <source>complement strand</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ORFWorker.cpp" line="78"/>
        <source>Name of the result annotations marking found ORFs</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ORFWorker.cpp" line="66"/>
        <source>A nucleotide sequence to search ORFs in. Protein sequences are skipped.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ORFWorker.cpp" line="68"/>
        <source>A set of annotations marking ORFs found in the sequence.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ORFWorker.cpp" line="79"/>
        <source>Which genetic code should be used for translating the input nucleotide sequence.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ORFWorker.cpp" line="94"/>
        <source>ORF marker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ORFWorker.cpp" line="95"/>
        <source>Finds Open Reading Frames (ORFs) in each supplied nucleotide sequence, stores found regions as annotations.&lt;p&gt;Protein sequences are skipped if any supplied to input.&lt;p&gt;&lt;dfn&gt;ORFs are DNA sequence regions that could potentially encode a protein, and usually give a good indication of the presence of a gene in the surrounding sequence.&lt;/dfn&gt;&lt;/p&gt;&lt;p&gt;In the sequence, ORFs are located between a start-code sequence (initiation codon) and a stop-code sequence (termination codon), defined by the selected genetic code.&lt;/p&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ORFWorker.cpp" line="78"/>
        <source>Annotate as</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ORFWorker.cpp" line="80"/>
        <source>Min length</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ORFWorker.cpp" line="224"/>
        <source>ORF: result name is empty, default name used</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ORFWorker.cpp" line="229"/>
        <source>ORF: Incorrect value: min-length must be greater then zero</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ORFWorker.cpp" line="230"/>
        <source>Incorrect value: min-length must be greater then zero</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ORFWorker.cpp" line="254"/>
        <source>Bad sequence supplied to ORFWorker: %1</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>U2::ORFAutoAnnotationsUpdater</name>
    <message>
        <location filename="../src/ORFMarkerTask.cpp" line="121"/>
        <source>ORFs</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::ORFDialog</name>
    <message>
        <source>cancel_button</source>
        <translation type="obsolete">Stop search</translation>
    </message>
    <message>
        <source>close_button</source>
        <translation type="obsolete">Close</translation>
    </message>
    <message>
        <location filename="../src/ORFDialog.cpp" line="222"/>
        <source>progress_%1%</source>
        <translation>Progress %1%. </translation>
    </message>
    <message>
        <location filename="../src/ORFDialog.cpp" line="224"/>
        <source>%1_results_found.</source>
        <translation>%1 results found.</translation>
    </message>
    <message>
        <location filename="../src/ORFDialog.cpp" line="274"/>
        <source>warning</source>
        <translation>Warning!</translation>
    </message>
    <message>
        <location filename="../src/ORFDialog.cpp" line="274"/>
        <source>results_list_not_empty_ask_clear</source>
        <translation>Results list contains results from the previous search. Clear?</translation>
    </message>
    <message>
        <location filename="../src/ORFDialog.cpp" line="169"/>
        <source>start_codons</source>
        <translation>Start codons:</translation>
    </message>
    <message>
        <location filename="../src/ORFDialog.cpp" line="170"/>
        <source>alt_start_codons</source>
        <translation>Alternative start codons:</translation>
    </message>
    <message>
        <location filename="../src/ORFDialog.cpp" line="171"/>
        <source>stop_codons</source>
        <translation>Stop codons:</translation>
    </message>
    <message>
        <location filename="../src/ORFDialog.cpp" line="441"/>
        <source>complem_strand</source>
        <translation>complement</translation>
    </message>
    <message>
        <location filename="../src/ORFDialog.cpp" line="441"/>
        <source>direct_strand</source>
        <translation>direct</translation>
    </message>
</context>
<context>
    <name>U2::ORFMarkerPlugin</name>
    <message>
        <location filename="../src/ORFMarkerPlugin.cpp" line="56"/>
        <source>orfname</source>
        <translation>ORF Marker</translation>
    </message>
    <message>
        <location filename="../src/ORFMarkerPlugin.cpp" line="56"/>
        <source>orfdesc</source>
        <translation>Finds open reading frames (ORF) in DNA sequence</translation>
    </message>
</context>
<context>
    <name>U2::ORFViewContext</name>
    <message>
        <location filename="../src/ORFMarkerPlugin.cpp" line="93"/>
        <source>Find ORFs...</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>U2::QDORFActor</name>
    <message>
        <location filename="../src/ORFQuery.cpp" line="60"/>
        <source>both strands</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ORFQuery.cpp" line="62"/>
        <source>direct strand</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ORFQuery.cpp" line="64"/>
        <source>complement strand</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ORFQuery.cpp" line="78"/>
        <source>, allow ORFs &lt;u&gt;starting with any codon&lt;/u&gt; other than terminator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ORFQuery.cpp" line="80"/>
        <source>, take into account &lt;u&gt;alternative start codons&lt;/u&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ORFQuery.cpp" line="83"/>
        <source>, &lt;u&gt;ignore non-terminated&lt;/u&gt; ORFs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ORFQuery.cpp" line="91"/>
        <source>Finds ORFs in &lt;u&gt;%1&lt;/u&gt; using the &lt;u&gt;%2&lt;/u&gt;.&lt;br&gt;Detects only ORFs &lt;u&gt;not shorter than %3, not longer than %4&lt;/u&gt;%5.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ORFQuery.cpp" line="140"/>
        <source>Bad sequence</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ORFQuery.cpp" line="143"/>
        <source>ORF find</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ORFQuery.cpp" line="187"/>
        <source>ORF</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ORFQuery.cpp" line="188"/>
        <source>Finds Open Reading Frames (ORFs) in supplied nucleotide sequence, stores found regions as annotations.&lt;p&gt;Protein sequences are skipped if any.&lt;p&gt;&lt;dfn&gt;ORFs are DNA sequence regions that could potentially encode a protein, and usually give a good indication of the presence of a gene in the surrounding sequence.&lt;/dfn&gt;&lt;/p&gt;&lt;p&gt;In the sequence, ORFs are located between a start-code sequence (initiation codon) and a stop-code sequence (termination codon), defined by the selected genetic code.&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ORFQuery.cpp" line="200"/>
        <source>Maximum length of annotation allowed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ORFQuery.cpp" line="201"/>
        <source>Require stop codon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ORFQuery.cpp" line="202"/>
        <source>Ignore boundary ORFs which last beyond the search region (i.e. have no stop codon within the range).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ORFQuery.cpp" line="196"/>
        <source>Genetic code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ORFQuery.cpp" line="196"/>
        <source>Which genetic code should be used for translating the input nucleotide sequence.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ORFQuery.cpp" line="197"/>
        <source>Min length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ORFQuery.cpp" line="198"/>
        <source>Require init codon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ORFQuery.cpp" line="199"/>
        <source>Allow alternative codons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ORFQuery.cpp" line="200"/>
        <source>Max length</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
